@@ -33,8 +33,8 @@ spacer1.writeConfig("length", "10")
 
 var kicker = panel.addWidget("org.kde.plasma.kicker")
 kicker.writeConfig("customButtonImage", "/usr/share/pixmaps/ubuntustudio-logo-menu.png")
-kicker.writeConfig("favoriteApps", "preferred://browser,org.kde.discover.desktop,systemsettings.desktop,org.kde.dolphin.desktop,org.kde.kate.desktop,patchance.desktop,ardour.desktop,com.obsproject.Studio.desktop,org.kde.krita.desktop,gimp.desktop,org.kde.kdenlive.desktop,org.kde.digikam.desktop,org.darktable.darktable.desktop")
 kicker.writeConfig("showAppsByName", "true")
+kicker.writeConfig("showIconsRootLevel", "true")
 kicker.currentConfigGroup = ["Shortcuts"]
 kicker.writeConfig("global", "Alt+F1")
 
